@@ -1,4 +1,3 @@
-// ;-*-C++-*-
 /*
  *       File name:  libsigfile/page.cc
  *         Project:  Aghermann
@@ -38,7 +37,8 @@ const char* const sigfile::SPage::score_names[TScore::TScore_total] = {
 
 
 float
-sigfile::CHypnogram::percent_scored( float *nrem_p, float *rem_p, float *wake_p) const
+sigfile::CHypnogram::
+percent_scored( float *nrem_p, float *rem_p, float *wake_p) const
 {
 	if ( nrem_p )
 		*nrem_p = (float)count_if( _pages.begin(), _pages.end(),
@@ -57,7 +57,8 @@ sigfile::CHypnogram::percent_scored( float *nrem_p, float *rem_p, float *wake_p)
 
 
 sigfile::CHypnogram::TError
-sigfile::CHypnogram::save( const char* fname) const
+sigfile::CHypnogram::
+save( const char* fname) const
 {
 	ofstream of (fname, ios_base::trunc);
 	if ( not of.good() )
@@ -65,14 +66,15 @@ sigfile::CHypnogram::save( const char* fname) const
 
 	of << _pagesize << endl;
 	for ( size_t p = 0; p < _pages.size(); ++p )
-		of << (*this)[p].NREM << '\t' << (*this)[p].REM << '\t' << (*this)[p].Wake << endl;
+		of << operator[](p).NREM << '\t' << operator[](p).REM << '\t' << operator[](p).Wake << endl;
 
 	return CHypnogram::TError::ok;
 }
 
 
 sigfile::CHypnogram::TError
-sigfile::CHypnogram::load( const char* fname)
+sigfile::CHypnogram::
+load( const char* fname)
 {
 	ifstream f (fname);
 	if ( not f.good() )
@@ -104,16 +106,17 @@ sigfile::CHypnogram::load( const char* fname)
 
 
 int
-sigfile::CHypnogram::save_canonical( const char *fname) const
+sigfile::CHypnogram::
+save_canonical( const char *fname) const
 {
 	FILE *f = fopen( fname, "w");
 	if ( !f )
 		return -1;
 
 	for ( size_t p = 0; p < pages(); ++p ) {
-		float	N = (*this)[p].NREM,
-			R = (*this)[p].REM,
-			W = (*this)[p].Wake;
+		float	N = operator[](p).NREM,
+			R = operator[](p).REM,
+			W = operator[](p).Wake;
 		fprintf( f, "%s\n",
 			 N > .7 ?"NREM4"
 			 : N > .4 ?"NREM3"
@@ -137,8 +140,9 @@ sigfile::CHypnogram::save_canonical( const char *fname) const
 
 
 int
-sigfile::CHypnogram::load_canonical( const char *fname,
-				     const TCustomScoreCodes& custom_score_codes)
+sigfile::CHypnogram::
+load_canonical( const char *fname,
+		const TCustomScoreCodes& custom_score_codes)
 {
 	ifstream f (fname);
 	if ( !f.good() )
@@ -179,11 +183,14 @@ sigfile::CHypnogram::load_canonical( const char *fname,
 			;
 		}
 
-		(*this)[p++] = P;
+		operator[](p++) = P;
 	}
 
 	return f.eof() ? 0 : 1;
 }
 
-
-// EOF
+// Local Variables:
+// Mode: c++
+// indent-tabs-mode: 8
+// tab-width: 8
+// End:
