@@ -1,4 +1,3 @@
-// ;-*-C++-*-
 /*
  *       File name:  tools/edfhed.cc
  *         Project:  Aghermann
@@ -11,17 +10,27 @@
  */
 
 
-#include <argp.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <utime.h>
-#include <stdlib.h>
-
+#include <cstdlib>
 #include <iostream>
-#include "../libsigfile/edf.hh"
-#include "../libsigfile/source.hh"
-#include "../common/fs.hh"
+
+//#include <argp.h>
+#include "common/fs.hh"
+#include "libsigfile/typed-source.hh"
+#include "libsigfile/edf.hh"
+
+// there's some deep and curious issue argp.h brings up if it is
+// included before libsigfile/source.hh, causing g++-4.8 to errors such as this:
+//
+//  /usr/local/stow/gcc-4.8/lib/gcc/x86_64-unknown-linux-gnu/4.8.0/include/smmintrin.h: In function ‘__m128i _mm_max_epu32(__m128i, __m128i)’:
+//  /usr/local/stow/gcc-4.8/lib/gcc/x86_64-unknown-linux-gnu/4.8.0/include/smmintrin.h:318: error: cannot convert ‘__v4si {aka int}’ to ‘__vector(4) int’ for argument ‘1’ to ‘__vector(4) int __builtin_ia32_pmaxud128(__vector(4) int, __vector(4) int)’
+//     return (__m128i) __builtin_ia32_pmaxud128 ((__v4si)__X, (__v4si)__Y);
+//
+// which must have to do with __vector clashing with some c++-specific
+// definition. Changing the order lets it go down all well. Whatever.
+#include <argp.h>
 
 #include "config.h"
 
@@ -34,6 +43,7 @@ static char doc[] =
 
 static struct argp_option options[] = {
        {"no-channels",		'b', 0,	0, "Only dump general header fields (no channel details)"},
+       {"with-annotations",	'a', 0,	0, "List embedded annotations"},
        {"set",			's', "[CH:]FIELD:VALUE", 0, "Set FIELD to VALUE (possibly in channel CH)" },
        {"id-from-tree",		'R', 0,	0, "Set 'recording_id' field to Subject/Session/Episode given current file location"},
        {"from-mtime",		'T', 0,	0, "Set 'recording_date' and 'recording_time' fields to file modification date/time"},
@@ -91,7 +101,8 @@ struct SSettable {
 			if ( 3 == sscanf( pv, "%u:%20[a-z_]:%80s", &h, p, v) && h != -1 ) {
 				channel = h - 1;  // base 0
 				if ( strcmp( p, "label") == 0 ) {
-					if ( not sigfile::SChannel::channel_follows_system1020( v) )
+					sigfile::SChannel X (p);
+					if ( X.type() != sigfile::SChannel::TType::eeg )
 						printf( "Note: Channel label \"%s\" does not follow System 10-20\n", v);
 					which = ch_label;
 				} else if ( strcmp( p, "transducer_type") == 0 ) {
@@ -146,11 +157,13 @@ struct SArguments {
 	std::vector<SSettable>
 		settables;
 	bool	header_only:1,
+		with_annotations:1,
 		from_tree:1,
 		from_timestamp:1,
 		to_timestamp:1;
 	SArguments()
 	      : header_only (false),
+		with_annotations (false),
 		from_tree (false),
 		from_timestamp (false),
 		to_timestamp (false)
@@ -168,6 +181,9 @@ parse_opt( int key, char *arg, struct argp_state *state)
 	case 'b':
 		Q.header_only = true;
 		break;
+	case 'a':
+		Q.with_annotations = true;
+		break;
 	case 'R':
 		Q.from_tree = true;
 		break;
@@ -245,8 +261,7 @@ set_recording_datetime_from_mtime( sigfile::CEDFFile& F)
 static int
 set_mtime_from_recording_datetime( sigfile::CEDFFile& F)
 {
-	if ( F.status() & sigfile::CEDFFile::date_unparsable ||
-	     F.status() & sigfile::CEDFFile::time_unparsable ) {
+	if ( F.status() & sigfile::CSource::bad_datetime ) {
 		fprintf( stderr, "Error: Bad recording_date or _time fields; not setting file mtime");
 		return -1;
 	}
@@ -267,7 +282,7 @@ set_session_and_episode_from_tree( sigfile::CEDFFile& F)
 	// filename can be anything, including a symlink
 	bool	is_path_absolute = (F.filename()[0] == '/');
 	list<string> pe = agh::fs::path_elements( string (is_path_absolute ? "" : "./") + F.filename());
-	string	episode = agh::fs::make_fname_base( pe.back(), ".edf", false);
+	string	episode = agh::fs::make_fname_base( pe.back(), ".edf", agh::fs::TMakeFnameOption::normal);
 
 	string	in_dir = string (is_path_absolute ? "/" : "") + agh::str::join( list<string> (pe.begin(), prev(pe.end())), "/") + "/.";
 	// a symlink from ./filename.edf would resolve somewhere else,
@@ -313,7 +328,11 @@ main( int argc, char **argv)
 						    sigfile::CEDFFile::no_field_consistency_check);
 			if ( Opts.settables.empty() &&
 			     not Opts.from_timestamp && not Opts.from_tree && not Opts.to_timestamp ) {
-				cout << F.details( not Opts.header_only) << endl;
+				cout << F.details(
+					0
+					| (Opts.header_only ? 0 : sigfile::CEDFFile::with_channels)
+					| (Opts.with_annotations ? sigfile::CEDFFile::with_annotations : 0))
+				     << endl;
 			} else {
 				if ( Opts.to_timestamp ) {
 					set_mtime_from_recording_datetime( F);
@@ -403,5 +422,8 @@ main( int argc, char **argv)
 }
 
 
-
-// eof
+// Local Variables:
+// Mode: c++
+// indent-tabs-mode: 8
+// tab-width: 8
+// End:
